@@ -7,7 +7,7 @@ Panda::XS - useful features and typemaps for XS modules.
 
 =cut
 
-our $VERSION = '0.1.6';
+our $VERSION = '0.1.9';
 require Panda::XSLoader;
 Panda::XSLoader::load();
 
@@ -1449,6 +1449,17 @@ Removes payload from $target. Returns true if any payload has been removed.
 
 Same as sv_* but $target must be reference to perl object.
 
+=head4 any_payload_attach ($target, $payload)
+
+=head4 any_payload ($target)
+
+=head4 any_payload_exists ($target)
+
+=head4 any_payload_detach ($target)
+
+Same as sv_* or rv_*, but if $target is ref then payload will be attached/detached from referenced object, 
+otherwise from $target itself.
+
 =head1 CAVEATS
 
 If module A binary depends on module B and module B updates and becomes binary incompatible, undefined behaviour may happen.
