@@ -1,9 +1,9 @@
 #pragma once
 #include <stdint.h>
+#include <stddef.h>
 
 #ifdef CPP11X
 #  include <memory>
-#  include <type_traits>
 #endif
 
 namespace panda {
@@ -47,18 +47,15 @@ struct IsRefCounted {
     static const bool value = HasRelease<T>::value && HasRetain<T>::value;
 };
 
-class RefCounted {
-    private:
-    mutable int32_t _refcnt;
-
-    protected:
-    RefCounted () : _refcnt(0) {}
-    virtual ~RefCounted () {}
-
-    public:
+struct RefCounted {
     void    retain  () const { ++_refcnt; }
     void    release () const { if (--_refcnt <= 0) delete this; }
     int32_t refcnt  () const { return _refcnt; }
+protected:
+    RefCounted () : _refcnt(0) {}
+    virtual ~RefCounted () {}
+private:
+    mutable int32_t _refcnt;
 };
 
 template <typename T, bool A = IsRefCounted<T>::value>
